@@ -299,7 +299,7 @@ mapi_config_utils_authenticator_try_password_sync (ESourceAuthenticator *auth,
 
 GType e_mapi_config_utils_authenticator_get_type (void) G_GNUC_CONST;
 
-static void e_mapi_config_utils_authenticator_authenticator_init (ESourceAuthenticatorInterface *interface);
+static void e_mapi_config_utils_authenticator_authenticator_init (ESourceAuthenticatorInterface *iface);
 
 G_DEFINE_TYPE_EXTENDED (EMapiConfigUtilsAuthenticator, e_mapi_config_utils_authenticator, G_TYPE_OBJECT, 0,
 	G_IMPLEMENT_INTERFACE (E_TYPE_SOURCE_AUTHENTICATOR, e_mapi_config_utils_authenticator_authenticator_init))
@@ -327,9 +327,9 @@ e_mapi_config_utils_authenticator_class_init (EMapiConfigUtilsAuthenticatorClass
 }
 
 static void
-e_mapi_config_utils_authenticator_authenticator_init (ESourceAuthenticatorInterface *interface)
+e_mapi_config_utils_authenticator_authenticator_init (ESourceAuthenticatorInterface *iface)
 {
-	interface->try_password_sync = mapi_config_utils_authenticator_try_password_sync;
+	iface->try_password_sync = mapi_config_utils_authenticator_try_password_sync;
 }
 
 static void
